@@ -126,6 +126,14 @@ QByteArray QOAuth1SignaturePrivate::signatureBaseString() const
     case QOAuth1Signature::HttpRequestMethod::Delete:
         base.append("DELETE");
         break;
+    case QOAuth1Signature::HttpRequestMethod::Custom:
+        if (!customVerb.isEmpty()) {
+            base.append(customVerb);
+        } else {
+            qCCritical(loggingCategory, "QOAuth1Signature: HttpRequestMethod::Custom requires "
+                                        "the verb to be set via setCustomMethodString");
+        }
+        break;
     default:
         qCCritical(loggingCategory, "QOAuth1Signature: HttpRequestMethod not supported");
     }
@@ -216,9 +224,8 @@ QOAuth1Signature::QOAuth1Signature(const QOAuth1Signature &other) : d(other.d)
     Move-constructs a QOAuth1Signature instance, taking over the
     private data \a other was using.
 */
-QOAuth1Signature::QOAuth1Signature(QOAuth1Signature &&other) : d(other.d)
+QOAuth1Signature::QOAuth1Signature(QOAuth1Signature &&other) : d(std::move(other.d))
 {
-    other.d = &QOAuth1SignaturePrivate::shared_null;
 }
 
 /*!
@@ -243,6 +250,37 @@ void QOAuth1Signature::setHttpRequestMethod(QOAuth1Signature::HttpRequestMethod
     d->method = method;
 }
 
+/*!
+    \since 5.13
+
+    Returns the custom method string.
+
+    \sa httpRequestMethod()
+*/
+QByteArray QOAuth1Signature::customMethodString() const
+{
+    return d->customVerb;
+}
+
+/*!
+    \since 5.13
+
+    Sets a custom request method. Will set the httpRequestMethod
+    to QOAuth1Signature::HttpRequestMethod::Custom and store the
+    \a verb to use it for the generation of the signature.
+
+    \note Using this method is required when working with custom verbs.
+    Setting only the request method will fail, as the signure needs to
+    know the actual verb.
+
+    \sa setHttpRequestMethod(), HttpRequestMethod
+*/
+void QOAuth1Signature::setCustomMethodString(const QByteArray &verb)
+{
+    d->method = QOAuth1Signature::HttpRequestMethod::Custom;
+    d->customVerb = verb;
+}
+
 /*!
     Returns the URL.
 */
